#
# spec file for package libhmac
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libhmac
%define lname	libhmac1
Version:        20230407
Release:        1.2
Summary:        Library to support various HMACs
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libhmac
Source:         https://github.com/libyal/libhmac/releases/download/%version/libhmac-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libhmac/releases/download/%version/libhmac-alpha-%version.tar.gz.asc
Source9:        %name.keyring
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20221218
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libuna) >= 20220611
BuildRequires:  pkgconfig(openssl) >= 1.0
# Various notes: https://en.opensuse.org/libyal

%description
A library and tools to support various Hash-based Message Authentication Codes (HMAC).

%package -n %lname
Summary:        Library to support various HMACs
Group:          System/Libraries

%description -n %lname
A library to support various Hash-based Message Authentication Codes (HMAC).

%package devel
Summary:        Development files for libhmac
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Development files for libhmac, a library to support various Hash-based Message Authentication Codes (HMAC).

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%package tools
Summary:        Utilities for HMACs
Group:          Productivity/File utilities

%description tools
Use hmacsum to calculate a Hash-based Message Authentication Code (HMAC) of the data in a file.

%prep
%autosetup -p1

%build
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log && exit 1
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libhmac.so.1*

%files devel
%_includedir/libhmac*
%_libdir/libhmac.so
%_libdir/pkgconfig/libhmac.pc
%_mandir/man3/libhmac.3*

%files tools
%_bindir/hmacsum
%_mandir/man1/hmacsum.1*

%changelog
* Sat Apr  8 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230407
  * No changelog was provided
* Sun Feb  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230205
  * Python bindings updates
  * openssl3 API update
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Apr 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220425
  * Unspecified updates to code and tests
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210419 (f97b507a)
  * No changelog was provided
- Add system-libs.patch
* Tue Dec 29 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200104
  * changes for SHA-512 HMAC
  * removed WinCrypt support
- removed    BuildRequires:  pkg-config
- added COPYING* to %%license line
* Wed Mar 27 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20180731
  * code cleanup
* Fri Jan  9 2015 Greg.Freemyer@gmail.com
- update to v0~20150104
  * 2015 update
  * worked on SHA224 support
  * worked on utility scripts
  * added hmacsum.1 man page
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- added hmacsum.1 man page to tools sub-project
- removed %%if opensuse logic.  NO longer needed now libyal is in security:forensics
- updated buildrequires based on new packages in OBS
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- update to v0~20140112
  * 2014 update
  * updated dependencies
  * updated .spec.in file
  * worked on tests
  * bug fixes
  * fixed missing libcrypto in .pc and .spec
  * fixed issue not freeing error state memory allocated by EVP
- Clean-up Summary / Description fields
* Wed Jul 31 2013 Greg.Freemyer@gmail.com
- update to v0~20130714
  * worked on SHA512 support
  * textual changes
  * updated dependencies
  * added libhmac_unused.h
  * 2013 update
  * changes for project move
- change to gz compression to simplyfy download/convert
- use libyal packages from factory when possible
* Tue Apr 23 2013 Greg.Freemyer@gmail.com
- reorder BuildRequires and add comments to explain why some are commented out
- run spec-cleaner
* Wed Apr  3 2013 jengelh@inai.de
- Initial package (version 0~20121225) for build.opensuse.org
